# {project_name} — Memory Index

> Auto-generated by `atlasmemory summary`. Do not edit manually.

## Systems

| System | Owner | Last Verified | Status |
|--------|-------|---------------|--------|

## Decisions

| # | Title | Date | Status |
|---|-------|------|--------|

## Gotchas

| Gotcha | Severity | Systems |
|--------|----------|---------|

## Research

| Topic | Date | Status |
|-------|------|--------|

## Team

| Person | Role | Current Focus |
|--------|------|---------------|
